@@ -28,7 +28,7 @@ import graphviz
 import graphviz.backend
 from dtreeviz.shadow import *
 from sklearn import tree
-from drop_bp_cords import drop_bp_cords, GenerateMetaDataFileHeaders
+from simba.drop_bp_cords import drop_bp_cords, GenerateMetaDataFileHeaders
 from sklearn.metrics import make_scorer, accuracy_score, precision_score, recall_score, f1_score
 from sklearn.model_selection import cross_val_score, cross_validate
 # import timeit
@@ -200,14 +200,17 @@ def trainmodel2(inifile):
     targetFrameRows = trainDf.loc[trainDf[classifierName] == 1]
     print('# of ' + str(classifierName) + ' frames in dataset: ' + str(totalTargetframes))
     if under_sample_setting == 'Random undersample':
-        print('Performing undersampling...')
-        under_sample_ratio = config.getfloat('create ensemble settings', 'under_sample_ratio')
-        nonTargetFrameRows = trainDf.loc[trainDf[classifierName] == 0]
-        nontargetFrameRowsSize = int(len(targetFrameRows) * under_sample_ratio)
-        nonTargetFrameRows = nonTargetFrameRows.sample(nontargetFrameRowsSize, replace=False)
-        trainDf = pd.concat([targetFrameRows, nonTargetFrameRows])
-        target_train = trainDf.pop(classifierName).values
-        data_train = trainDf
+        try:
+            print('Performing undersampling...')
+            under_sample_ratio = config.getfloat('create ensemble settings', 'under_sample_ratio')
+            nonTargetFrameRows = trainDf.loc[trainDf[classifierName] == 0]
+            nontargetFrameRowsSize = int(len(targetFrameRows) * under_sample_ratio)
+            nonTargetFrameRows = nonTargetFrameRows.sample(nontargetFrameRowsSize, replace=False)
+            trainDf = pd.concat([targetFrameRows, nonTargetFrameRows])
+            target_train = trainDf.pop(classifierName).values
+            data_train = trainDf
+        except ValueError:
+            print('Undersampling failed: the undersampling ratio for the model is likely too high - there are not enough non-events too sample. Fix this by decreasing the undersampling ratio.')
     if under_sample_setting != 'Random undersample':
         target_train = trainDf.pop(classifierName).values
         under_sample_ratio = 'NaN'
