@@ -2,7 +2,7 @@ import warnings
 warnings.filterwarnings('ignore',category=FutureWarning)
 warnings.filterwarnings('ignore',category=DeprecationWarning)
 from configparser import ConfigParser, MissingSectionHeaderError
-import os
+import os, glob
 import pandas as pd
 from sklearn.ensemble import RandomForestClassifier
 from sklearn.model_selection import train_test_split
@@ -144,12 +144,12 @@ def train_multimodel(configini):
 
     # READ IN DATA FOLDER AND REMOVE ALL NON-FEATURE VARIABLES (POP DLC COORDINATE DATA AND TARGET DATA)
     features = pd.DataFrame()
-    print('Reading in ' + str(len(os.listdir(data_folder))) + ' annotated files...')
+    print('Reading in ' + str(len(glob.glob(data_folder + '/*.csv'))) + ' annotated files...')
 
     for p in os.listdir(data_folder):
         if (".csv") in p:
             currentFn = os.path.join(data_folder, p)
-            df = pd.read_csv(currentFn)
+            df = pd.read_csv(currentFn, index_col=0)
             features = features.append(df, ignore_index=True)
     features = features.loc[:, ~features.columns.str.contains('^Unnamed')]
     baseFeatureFrame = features.drop(["scorer"], axis=1, errors='ignore')
@@ -214,14 +214,17 @@ def train_multimodel(configini):
         trainDf[classifierName] = target_train
         print('# of ' + str(classifierName) + ' frames in dataset: ' + str(totalTargetframes))
         if under_sample_setting == 'Random undersample':
-            print('Performing undersampling...')
-            targetFrameRows = trainDf.loc[trainDf[classifierName] == 1]
-            nonTargetFrameRows = trainDf.loc[trainDf[classifierName] == 0]
-            nontargetFrameRowsSize = int(len(targetFrameRows) * under_sample_ratio)
-            nonTargetFrameRows = nonTargetFrameRows.sample(nontargetFrameRowsSize, replace=False)
-            trainDf = pd.concat([targetFrameRows, nonTargetFrameRows])
-            target_train = trainDf.pop(classifierName).values
-            data_train = trainDf
+            try:
+                print('Performing undersampling...')
+                targetFrameRows = trainDf.loc[trainDf[classifierName] == 1]
+                nonTargetFrameRows = trainDf.loc[trainDf[classifierName] == 0]
+                nontargetFrameRowsSize = int(len(targetFrameRows) * under_sample_ratio)
+                nonTargetFrameRows = nonTargetFrameRows.sample(nontargetFrameRowsSize, replace=False)
+                trainDf = pd.concat([targetFrameRows, nonTargetFrameRows])
+                target_train = trainDf.pop(classifierName).values
+                data_train = trainDf
+            except ValueError:
+                print('Undersampling failed: the undersampling ratio for the specific model is likely too high - there are not enough non-events too sample. Fix this by decreasing the undersampling ratio.')
         if under_sample_setting != 'Random undersample':
             target_train = trainDf.pop(classifierName).values
             under_sample_ratio = 'NaN'
